@@ -1,8 +1,8 @@
 """
 # -*- coding: utf-8 -*-
-#====================================================================================================================
+#===============================================================================
 #
-# Copyright (C) 2013 Laurent Champagnac
+# Copyright (C) 2013/2014 Laurent Champagnac
 #
 #
 #
@@ -18,8 +18,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#====================================================================================================================
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#===============================================================================
 """
 import ast
 import platform
@@ -63,6 +63,8 @@ class SolBase(object):
     # Fork stuff
     _masterProcess = True
 
+
+
     #===============================
     # DATE & MS
     #===============================
@@ -125,8 +127,10 @@ class SolBase(object):
 
         # Get delta
         if dtEnd:
+            # noinspection PyUnresolvedReferences
             delta = dtEnd - dtStart
         else:
+            # noinspection PyTypeChecker
             delta = cls.dateCurrent() - dtStart
 
         # From : http://stackoverflow.com/questions/4898687/python-parsing-timestamps-and-calculating-time-differences-in-milliseconds
@@ -161,12 +165,12 @@ class SolBase(object):
     @classmethod
     def getMachineName(cls):
         """
-        Get machine name, upper cased
+        Get machine name
         :return: Machine name
         :rtype: str
         """
 
-        return platform.uname()[1].upper()
+        return platform.uname()[1]
 
     #===============================
     # MISC
@@ -287,10 +291,12 @@ class SolBase(object):
     #===============================
 
     @classmethod
-    def voodooInit(cls):
+    def voodooInit(cls, aggressive=True):
         """
         Global initialization, to call asap.
         Apply gevent stuff & default logging configuration.
+        :param aggressive: bool
+        :type aggressive: bool
         :return Nothing.
         """
 
@@ -305,8 +311,8 @@ class SolBase(object):
                 return
 
             # Fire the voodoo magic :)
-            lifecyclelogger.info("Voodoo : gevent : entering")
-            monkey.patch_all()
+            lifecyclelogger.info("Voodoo : gevent : entering, aggressive=%s", aggressive)
+            monkey.patch_all(aggressive=aggressive)
             lifecyclelogger.info("Voodoo : gevent : entering")
 
             # Initialize log level to INFO
@@ -561,7 +567,7 @@ class SolBase(object):
         :param myString: A String.
         :return: Return true if the provided myString is a str or an unicode, not empty.. False otherwise.
         """
-        if SolBase.isString(myString) == False:
+        if not SolBase.isString(myString):
             return False
         else:
             return len(myString) > 0
@@ -590,7 +596,7 @@ class SolBase(object):
         if myInt is None:
             return False
         # Caution, boolean is an integer...
-        elif SolBase.isBoolean(myInt) == True:
+        elif SolBase.isBoolean(myInt):
             return False
         else:
             return isinstance(myInt, (int, long))
@@ -602,6 +608,6 @@ class SolBase(object):
         :param cls: Our class.
         :return: A String
         """
-        return "pid={0} ppid={1} master={2}".format(os.getpid(), os.getppid(), SolBase.getMasterProcess())
+        return "pid={0}, ppid={1}".format(os.getpid(), os.getppid())
 
 
