@@ -1,6 +1,6 @@
 """
 # -*- coding: utf-8 -*-
-#====================================================================================================================
+#===============================================================================
 #
 # Copyright (C) 2013/2014 Laurent Champagnac
 #
@@ -16,8 +16,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#====================================================================================================================
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#===============================================================================
 """
 
 from _socket import SOL_SOCKET, SOL_TCP, SO_KEEPALIVE, TCP_KEEPIDLE, TCP_KEEPINTVL, TCP_KEEPCNT
@@ -109,7 +109,6 @@ class TcpSimpleClient(TcpSocketManager):
         self.onDisconnectNotifyPoolCallbackCall = True
         self.onDisconnectNotifyPoolCallback = None
 
-
     #================================
     # POOL METHOD
     #================================
@@ -170,7 +169,7 @@ class TcpSimpleClient(TcpSocketManager):
             self.unsetInternalFatalErrorForReconnect()
 
             # Check
-            if self.isConnected == True:
+            if self.isConnected:
                 logger.warn("TcpSimpleClient : connect : already connected, doing nothing, self=%s", self)
                 return False
 
@@ -184,12 +183,12 @@ class TcpSimpleClient(TcpSocketManager):
             #------------------------
             # ALLOC
             #------------------------
-            if self._tcpClientConfig.sslEnable == True:
-                if self._tcpClientConfig.proxyEnable == True:
+            if self._tcpClientConfig.sslEnable:
+                if self._tcpClientConfig.proxyEnable:
                     #------------------------
                     # PROXY ON, SSL ON
                     #------------------------
-                    if self._tcpClientConfig.debugLog == True:
+                    if self._tcpClientConfig.debugLog:
                         logger.info("TcpSimpleClient : Alloc : PROXY ON/SSL ON, self=%s", self)
                     else:
                         logger.debug("TcpSimpleClient : Alloc : PROXY ON/SSL ON, self=%s", self)
@@ -207,24 +206,24 @@ class TcpSimpleClient(TcpSocketManager):
                     #------------------------
                     # PROXY OFF, SSL ON
                     #------------------------
-                    if self._tcpClientConfig.debugLog == True:
+                    if self._tcpClientConfig.debugLog:
                         logger.info("TcpSimpleClient : Alloc : PROXY OFF/SSL ON, self=%s", self)
                     else:
                         logger.debug("TcpSimpleClient : Alloc : PROXY OFF/SSL ON, self=%s", self)
                         pass
 
                     # Alloc
-                    self.current = gevent.socket.socket()
+                    self.currentSocket = gevent.socket.socket()
 
                     # Wrap
                     self.currentSocket = SSLSocket(self.currentSocket, do_handshake_on_connect=False,
                                                    ssl_version=PROTOCOL_TLSv1)
             else:
-                if self._tcpClientConfig.proxyEnable == True:
+                if self._tcpClientConfig.proxyEnable:
                     #------------------------
                     # PROXY ON, SSL OFF
                     #------------------------
-                    if self._tcpClientConfig.debugLog == True:
+                    if self._tcpClientConfig.debugLog:
                         logger.info("TcpSimpleClient : Alloc : PROXY ON/SSL OFF, self=%s", self)
                     else:
                         logger.debug("TcpSimpleClient : Alloc : PROXY ON/SSL OFF, self=%s", self)
@@ -240,7 +239,7 @@ class TcpSimpleClient(TcpSocketManager):
                     #------------------------
                     # PROXY OFF, SSL OFF
                     #------------------------
-                    if self._tcpClientConfig.debugLog == True:
+                    if self._tcpClientConfig.debugLog:
                         logger.info("TcpSimpleClient : Alloc : PROXY OFF/SSL OFF, self=%s", self)
                     else:
                         logger.debug("TcpSimpleClient : Alloc : PROXY OFF/SSL OFF, self=%s", self)
@@ -266,7 +265,7 @@ class TcpSimpleClient(TcpSocketManager):
             address = (self._tcpClientConfig.targetAddr, self._tcpClientConfig.targetPort)
 
             # Connect
-            if self._tcpClientConfig.debugLog == True:
+            if self._tcpClientConfig.debugLog:
                 logger.info("TcpSimpleClient : connect : starting, ssl=%s, timeout=%s, self=%s",
                             self._tcpClientConfig.sslEnable,
                             self._tcpClientConfig.timeoutMs, self)
@@ -283,7 +282,7 @@ class TcpSimpleClient(TcpSocketManager):
             self._remotePort = self.currentSocket.getpeername()[1]
 
             # Log
-            if self._tcpClientConfig.debugLog == True:
+            if self._tcpClientConfig.debugLog:
                 logger.info("TcpSimpleClient : connected, %s:%s to %s:%s, self=%s", self._localAdr, self._localPort,
                             self._remoteAdr, self._remotePort, self)
 
@@ -294,9 +293,9 @@ class TcpSimpleClient(TcpSocketManager):
             #------------------------
             # POST CONNECT
             #------------------------
-            if self._tcpClientConfig.sslEnable == True:
+            if self._tcpClientConfig.sslEnable:
                 # Switch to SSL now
-                if self._tcpClientConfig.debugLog == True:
+                if self._tcpClientConfig.debugLog:
                     logger.info("TcpSimpleClient : PostConnect : PROXY ON/SSL ON, switching to SSL now, self=%s", self)
                 else:
                     logger.debug("TcpSimpleClient : PostConnect : PROXY ON/SSL ON, switching to SSL now, self=%s", self)
@@ -319,9 +318,9 @@ class TcpSimpleClient(TcpSocketManager):
             # POST CONNECT
             #------------------------
 
-            if self._tcpClientConfig.tcpKeepAliveEnabled == True:
+            if self._tcpClientConfig.tcpKeepAliveEnabled:
                 # Switch to TCP KA now
-                if self._tcpClientConfig.debugLog == True:
+                if self._tcpClientConfig.debugLog:
                     logger.info(
                         "TcpSimpleClient : PostConnect : TCP KA ON, switching to KA now, (on=%s/delay=%s/failed=%s/interval=%s), self=%s",
                         self._tcpClientConfig.tcpKeepAliveEnabled,
@@ -402,7 +401,7 @@ class TcpSimpleClient(TcpSocketManager):
             logger.debug("TcpSimpleClient : disconnect : entering, self=%s", self)
 
             # Check
-            if self.isConnected == False:
+            if not self.isConnected:
                 logger.debug("TcpSimpleClient : disconnect : not connected, doing nothing, self=%s", self)
                 return False
 
@@ -447,7 +446,7 @@ class TcpSimpleClient(TcpSocketManager):
                     goCall = True
 
             # Out of lock : call (ASYNC, because we may be called by read/write greenlet, which are going to be killed just after)
-            if goCall == True:
+            if goCall:
                 try:
                     # Call it synchronously (mantis 1907)
                     self.onDisconnectNotifyPoolCallback(self)
