@@ -1,6 +1,6 @@
 """
 # -*- coding: utf-8 -*-
-#====================================================================================================================
+#===============================================================================
 #
 # Copyright (C) 2013/2014 Laurent Champagnac
 #
@@ -16,8 +16,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#====================================================================================================================
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#===============================================================================
 """
 
 # Logger
@@ -109,7 +109,7 @@ class TcpServerConfig(object):
         logger.debug("TcpServerConfig : _setListenAddr called, listenAddr=%s, class=%s", listenAddr,
                      SolBase.getClassName(listenAddr))
 
-        if SolBase.isStringNotEmpty(listenAddr) == False:
+        if not SolBase.isStringNotEmpty(listenAddr):
             logger.error("TcpServerConfig : _setListenAddress : not a string or empty, class=%s",
                          SolBase.getClassName(listenAddr))
             raise Exception("TcpServerConfig : _setListenAddress : not a string or empty")
@@ -127,10 +127,10 @@ class TcpServerConfig(object):
         logger.debug("TcpServerConfig : _setListenPort called, listenPort=%s, class=%s", listenPort,
                      SolBase.getClassName(listenPort))
 
-        if SolBase.isString(listenPort) == True:
+        if SolBase.isString(listenPort):
             listenPort = SolBase.toInt(listenPort)
 
-        if SolBase.isInteger(listenPort) == False:
+        if not SolBase.isInteger(listenPort):
             logger.error("TcpServerConfig : _setListenPort : not a int, class=%s", SolBase.getClassName(listenPort))
             raise Exception("TcpServerConfig : _setListenPort : not a int")
         elif listenPort == 0:
@@ -150,10 +150,10 @@ class TcpServerConfig(object):
         logger.debug("TcpServerConfig : _setSslHandshakeTimeOutMs called, timeOutMs=%s, class=%s", timeOutMs,
                      SolBase.getClassName(timeOutMs))
 
-        if SolBase.isString(timeOutMs) == True:
+        if SolBase.isString(timeOutMs):
             timeOutMs = SolBase.toInt(timeOutMs)
 
-        if SolBase.isInteger(timeOutMs) == False:
+        if not SolBase.isInteger(timeOutMs):
             logger.error("TcpServerConfig : _setSslHandshakeTimeOutMs : not a int, class=%s",
                          SolBase.getClassName(timeOutMs))
             raise Exception("TcpServerConfig : _setSslHandshakeTimeOutMs : not a int")
@@ -171,10 +171,10 @@ class TcpServerConfig(object):
         logger.debug("TcpServerConfig : _setStopClientTimeoutMs called, timeOutMs=%s, class=%s", timeOutMs,
                      SolBase.getClassName(timeOutMs))
 
-        if SolBase.isString(timeOutMs) == True:
+        if SolBase.isString(timeOutMs):
             timeOutMs = SolBase.toInt(timeOutMs)
 
-        if SolBase.isInteger(timeOutMs) == False:
+        if not SolBase.isInteger(timeOutMs):
             logger.error("TcpServerConfig : _setStopClientTimeoutMs : not a int, class=%s",
                          SolBase.getClassName(timeOutMs))
             raise Exception("TcpServerConfig : _setStopClientTimeoutMs : not a int")
@@ -192,10 +192,10 @@ class TcpServerConfig(object):
         logger.debug("TcpServerConfig : _setStopServerTimeoutMs called, timeOutMs=%s, class=%s", timeOutMs,
                      SolBase.getClassName(timeOutMs))
 
-        if SolBase.isString(timeOutMs) == True:
+        if SolBase.isString(timeOutMs):
             timeOutMs = SolBase.toInt(timeOutMs)
 
-        if SolBase.isInteger(timeOutMs) == False:
+        if not SolBase.isInteger(timeOutMs):
             logger.error("TcpServerConfig : _setStopServerTimeoutMs : not a int, class=%s",
                          SolBase.getClassName(timeOutMs))
             raise Exception("TcpServerConfig : _setStopServerTimeoutMs : not a int")
@@ -214,10 +214,10 @@ class TcpServerConfig(object):
                      childProcessCount,
                      SolBase.getClassName(childProcessCount))
 
-        if SolBase.isString(childProcessCount) == True:
+        if SolBase.isString(childProcessCount):
             childProcessCount = SolBase.toInt(childProcessCount)
 
-        if SolBase.isInteger(childProcessCount) == False:
+        if not SolBase.isInteger(childProcessCount):
             logger.error("TcpServerConfig : _setChildProcessCount : not a int, class=%s",
                          SolBase.getClassName(childProcessCount))
             raise Exception("TcpServerConfig : _setChildProcessCount : not a int")
@@ -240,7 +240,7 @@ class TcpServerConfig(object):
         if SolBase.isString(myBool):
             myBool = SolBase.toBool(myBool)
 
-        if SolBase.isBoolean(myBool) == False:
+        if not SolBase.isBoolean(myBool):
             logger.error("TcpServerConfig : _setAutoStart : not a boolean, class=%s", SolBase.getClassName(myBool))
             raise Exception("TcpServerConfig : _setAutoStart : not a boolean")
         else:
@@ -259,7 +259,7 @@ class TcpServerConfig(object):
         if SolBase.isString(myBool):
             myBool = SolBase.toBool(myBool)
 
-        if SolBase.isBoolean(myBool) == False:
+        if not SolBase.isBoolean(myBool):
             logger.error("TcpServerConfig : _setOnStopCallClientStopSynch : not a boolean, class=%s",
                          SolBase.getClassName(myBool))
             raise Exception("TcpServerConfig : _setOnStopCallClientStopSynch : not a boolean")
@@ -281,7 +281,7 @@ class TcpServerConfig(object):
         if SolBase.isString(isEnable):
             isEnable = SolBase.toBool(isEnable)
 
-        if SolBase.isBoolean(isEnable) == False:
+        if not SolBase.isBoolean(isEnable):
             logger.error("TcpServerConfig : _setSslEnable : not a boolean, class=%s", SolBase.getClassName(isEnable))
             raise Exception("TcpServerConfig : _setSslEnable : not a boolean")
         else:
@@ -302,11 +302,11 @@ class TcpServerConfig(object):
             self._sslKeyFile = ""
             return
 
-        if SolBase.isStringNotEmpty(keyFile) == False:
+        if not SolBase.isStringNotEmpty(keyFile):
             logger.warn("TcpServerConfig : _setSslKeyFile : not a string, class=%s", SolBase.getClassName(keyFile))
             raise Exception("TcpServerConfig : _setSslKeyFile : not a string")
 
-        if FileUtility.isFileExist(keyFile) == False:
+        if not FileUtility.isFileExist(keyFile):
             logger.warn("_setSslKeyFile : keyFile do not exist or is not accessible, keyFile=%s", keyFile)
 
         # Set
@@ -327,13 +327,13 @@ class TcpServerConfig(object):
             self._sslCertificateFile = ""
             return
 
-        if SolBase.isStringNotEmpty(certFile) == False:
+        if not SolBase.isStringNotEmpty(certFile):
             logger.error("TcpServerConfig : _setSslCertificateFile : not a string, class=%s",
                          SolBase.getClassName(certFile))
             raise Exception("TcpServerConfig : _setSslCertificateFile : not a string")
 
         # Check
-        if FileUtility.isFileExist(certFile) == False:
+        if not FileUtility.isFileExist(certFile):
             logger.warn("_setSslCertificateFile : certFile do not exist or is not accessible, certFile=%s", certFile)
 
         # Set
@@ -459,10 +459,10 @@ class TcpServerConfig(object):
                      checkMs,
                      SolBase.getClassName(checkMs))
 
-        if SolBase.isString(checkMs) == True:
+        if SolBase.isString(checkMs):
             checkMs = SolBase.toInt(checkMs)
 
-        if SolBase.isInteger(checkMs) == False:
+        if not SolBase.isInteger(checkMs):
             logger.error("TcpServerConfig : _setSocketMinCheckIntervalMs : not a int, class=%s",
                          SolBase.getClassName(checkMs))
             raise Exception("TcpServerConfig : _setSocketMinCheckIntervalMs : not a int")
@@ -481,10 +481,10 @@ class TcpServerConfig(object):
                      timeOutMs,
                      SolBase.getClassName(timeOutMs))
 
-        if SolBase.isString(timeOutMs) == True:
+        if SolBase.isString(timeOutMs):
             timeOutMs = SolBase.toInt(timeOutMs)
 
-        if SolBase.isInteger(timeOutMs) == False:
+        if not SolBase.isInteger(timeOutMs):
             logger.error("TcpServerConfig : _setSocketAbsoluteTimeOutMs : not a int, class=%s",
                          SolBase.getClassName(timeOutMs))
             raise Exception("TcpServerConfig : _setSocketAbsoluteTimeOutMs : not a int")
@@ -503,10 +503,10 @@ class TcpServerConfig(object):
                      timeOutMs,
                      SolBase.getClassName(timeOutMs))
 
-        if SolBase.isString(timeOutMs) == True:
+        if SolBase.isString(timeOutMs):
             timeOutMs = SolBase.toInt(timeOutMs)
 
-        if SolBase.isInteger(timeOutMs) == False:
+        if not SolBase.isInteger(timeOutMs):
             logger.error("TcpServerConfig : _setSocketRelativeTimeOutMs : not a int, class=%s",
                          SolBase.getClassName(timeOutMs))
             raise Exception("TcpServerConfig : _setSocketRelativeTimeOutMs : not a int")
